# tessbkgd
[![Licence](http://img.shields.io/badge/license-GPLv3-blue.svg?style=flat)](http://www.gnu.org/licenses/gpl-3.0.html)
[![PyPI version](https://badge.fury.io/py/tessbkgd.svg)](https://badge.fury.io/py/tessbkgd)

Custom TESS backgrounds for large target pixel files
